<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB; // Importar la clase DB

class ConciliacionFlujos extends Model
{
    // Define the table associated with the model
    protected $table = 'REGISTRO_ENTRADAS_SALIDAS';

    // If the table doesn't use timestamps, disable them
    public $timestamps = false;


    public static function getTablaConFlujos()
    {
        // Ejecuta una consulta personalizada
        return DB::select('SELECT 
                            reg.ID_REGISTRO,
                            MAX(reg.FECHA) AS FECHA,
                            MAX(c.CUENTA) AS CUENTA,
                            MAX(reg.ID_CAT) AS ID_CAT,
                            MAX(reg.DESCRIPCION) AS DESCRIPCION ,
                            MAX(reg.CARGO) AS CARGO,
                            MAX(reg.ABONO) AS ABONO,
                            MAX(cf.ID_FLUJO)AS ID_FLUJO,
                            MAX(cf.ID_BUCKET) AS ID_BUCKET,
                            MAX(cbu.BUCKET) AS BUCKET,
                            MAX(cf.ID_EDO_FLU_EFE) AS ID_EDO_FLU_EFE,
                            MAX(cef.EDO_FLU_EFE) AS EDO_FLU_EFE
                        FROM 
                            REGISTRO_ENTRADAS_SALIDAS reg
                        LEFT JOIN 
                            CONCILIACION_FLUJO cf ON reg.id_registro = cf.id_registro
                        LEFT JOIN 
                            CAT_COMPLETO c ON reg.ID_CAT = c.ID_CAT
                        LEFT JOIN 
                            CAT_EDO_FLU_EFE cef ON cef.ID_EDO_FLU_EFE = cf.ID_EDO_FLU_EFE
                        LEFT JOIN 
                            CAT_BUCKET cbu ON cbu.ID_BUCKET = cf.ID_BUCKET
                        WHERE 
                            c.Cuenta LIKE \'1.1.1%\'
                             OR c.Cuenta LIKE \'1.1.2%\'
                        GROUP BY 
                            reg.id_registro
                        ORDER BY 
                            reg.id_registro DESC');
    }

    public static function cat_fluEfe()
    {
        //traer datos
        
        $data = DB::table('CAT_EDO_FLU_EFE')
        ->select('ID_EDO_FLU_EFE', 'EDO_FLU_EFE')
        ->get();

        // devolver los datos
        return $data->toArray(); 
    }


    public static function updateCatflu($idValue,$catEdoFlu, $ID_REGISTRO=NULL)
    {
        //traer datos
        if($ID_REGISTRO){
            $rowsAffected = DB::table('CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $ID_REGISTRO)
            ->update(['ID_EDO_FLU_EFE' => $catEdoFlu]);
    
            // Devuelve true si se actualizaron una o más filas, de lo contrario false
            return $rowsAffected > 0;
        }else{
            $rowsAffected = DB::table('CONCILIACION_FLUJO')
            ->where('ID_FLUJO', $idValue)
            ->update(['ID_EDO_FLU_EFE' => $catEdoFlu]);
    
            // Devuelve true si se actualizaron una o más filas, de lo contrario false
            return $rowsAffected > 0;
        }
       
    }

    public static function updateBuckFlu($idValue,$bucket, $ID_REGISTRO=NULL)
    {
        //traer datos
        if($ID_REGISTRO){
            $rowsAffected = DB::table('CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $ID_REGISTRO)
            ->update(['ID_BUCKET' => $bucket]);
    
            // Devuelve true si se actualizaron una o más filas, de lo contrario false
            return $rowsAffected > 0;
        }else{
            $rowsAffected = DB::table('CONCILIACION_FLUJO')
            ->where('ID_FLUJO', $idValue)
            ->update(['ID_BUCKET' => $bucket]);
    
            // Devuelve true si se actualizaron una o más filas, de lo contrario false
            return $rowsAffected > 0;
        }
       
    }

    public static function insertFlu($idValue,$catEdoFlu)
    {
         // Realiza la inserción y devuelve el ID generado
        $idFlujo = DB::table('CONCILIACION_FLUJO')->insertGetId([
            'ID_REGISTRO' => $idValue,
            'ID_EDO_FLU_EFE' => $catEdoFlu
        ]);

        return $idFlujo;
    }

    public static function insertBk($idValue,$bucket)
    {
         // Realiza la inserción y devuelve el ID generado
        $idFlujo = DB::table('CONCILIACION_FLUJO')->insertGetId([
            'ID_REGISTRO' => $idValue,
            'ID_BUCKET' => $bucket
        ]);

        return $idFlujo;
    }

    public static function costos()
    {
        return DB::table('Finanzas.CAT_CENTRO_COSTOS')
                 ->select('ID_CENTRO_COSTO', 'CENTRO_COSTO')
                 ->get();
    }

    public static function valProrr($idvalue)
    {
        return DB::table('Finanzas.CONCILIACION_FLUJO')
        ->select('ID_CENTRO_COSTO', 'COSTO')
        ->where('ID_REGISTRO', $idvalue)
        ->get();

    }

    public static function updateCostosFlu($idValue, $centroCostos)
    {
        // Obtener los registros existentes en la base de datos para este $idValue
        $existingCostos = DB::table('Finanzas.CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $idValue)
            ->pluck('COSTO', 'ID_CENTRO_COSTO')
            ->toArray();

        // Obtener los buckets existentes en la base de datos para este $idValue
        $EdoFluEffs = DB::table('Finanzas.CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $idValue)
            ->pluck('ID_EDO_FLU_EFE', 'ID_CENTRO_COSTO')
            ->toArray();
        
        // Obtener el ID_BUCKET de algún registro existente
        $idBucket = DB::table('Finanzas.CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $idValue)
            ->value('ID_BUCKET');
        
        $newIds = [];
        $updated = false;

        // Buscar un registro con ID_CENTRO_COSTO y COSTO como null o vacío
        $existingNullCosto = DB::table('Finanzas.CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $idValue)
            ->whereNull('ID_CENTRO_COSTO')
            ->where(function ($query) {
                $query->whereNull('COSTO')->orWhere('COSTO', '0.00');
            })
            ->first();

        if ($existingNullCosto) {
            // Si se encuentra un registro existente con null o vacío, actualízalo con el primer centro de costo
            foreach ($centroCostos as $index => $centro) {
                if (!$updated) {
                    DB::table('Finanzas.CONCILIACION_FLUJO')
                        ->where('ID_REGISTRO', $idValue)
                        ->whereNull('ID_CENTRO_COSTO')
                        ->where(function ($query) {
                            $query->whereNull('COSTO')->orWhere('COSTO', '0.00');
                        })
                        ->update([
                            'ID_CENTRO_COSTO' => $centro['ID_CENTRO_COSTO'],
                            'COSTO' => $centro['VALUE']
                        ]);
                    unset($centroCostos[$index]); // Remover el centro de costo actualizado de la lista
                    $updated = true; // Marcar que ya hemos hecho la actualización
                }
            }
        }

        // Ahora manejar los costos adicionales que no fueron actualizados o si no había null para actualizar
        foreach ($centroCostos as $centro) {
            $idCentroCosto = $centro['ID_CENTRO_COSTO'];
            $value = $centro['VALUE'];

            // Verificar si el centro de costo ya existe
            if (array_key_exists($idCentroCosto, $existingCostos)) {
                // Si ya existe, actualizamos el COSTO
                DB::table('Finanzas.CONCILIACION_FLUJO')
                    ->where('ID_REGISTRO', $idValue)
                    ->where('ID_CENTRO_COSTO', $idCentroCosto)
                    ->update(['COSTO' => $value]);
            } else {
                // Si el centro de costo no existe, inserta uno nuevo
                $EdoFluEff = !empty($EdoFluEffs) ? reset($EdoFluEffs) : null;

                // Verificar si ya existe un ID_BUCKET
                if ($idBucket) {
                    // Insertar nuevo registro con el ID_BUCKET existente
                    $newId = self::insertCostosFlu($idValue, $idCentroCosto, $value, $EdoFluEff, $idBucket);
                } else {
                    // Insertar sin ID_BUCKET si no existe
                    $newId = self::insertCostosFlu($idValue, $idCentroCosto, $value, $EdoFluEff);
                }
                $newIds[] = $newId;
            }
        }

        // Obtener los IDs de los centros de costo existentes
        $existingIds = array_keys($existingCostos);
        $newCentroCostosIds = array_column($centroCostos, 'ID_CENTRO_COSTO');

        // Filtrar valores no válidos de $existingIds y $newCentroCostosIds
        $existingIds = array_filter($existingIds, function($id) {
            return !is_null($id) && $id !== '' && $id !== 0;
        });

        $newCentroCostosIds = array_filter($newCentroCostosIds, function($id) {
            return !is_null($id) && $id !== '' && $id !== 0;
        });

        // Determinar los IDs que deben eliminarse, excluyendo aquellos que tienen null en ID_CENTRO_COSTO
        $idsToDelete = array_diff($existingIds, $newCentroCostosIds);

        if (!empty($idsToDelete)) {
            // Eliminar registros con ID_CENTRO_COSTO definido que no están en la lista de nuevos centros de costo
            DB::table('Finanzas.CONCILIACION_FLUJO')
                ->where('ID_REGISTRO', $idValue)
                ->whereIn('ID_CENTRO_COSTO', $idsToDelete)
                ->delete();
        }

        // Retornar el ID más alto de los insertados (si se insertó alguno)
        return !empty($newIds) ? max($newIds) : null;
    }

    
    public static function insertCostosFlu($idValue, $idCentroCosto, $value, $EdoFluEff = null, $ID_BUCKET = null)
    {
        // Construir los datos de inserción básicos
        $insertData = [
            'ID_REGISTRO' => $idValue,
            'ID_CENTRO_COSTO' => $idCentroCosto,
            'COSTO' => $value,
            'ID_EDO_FLU_EFE' => $EdoFluEff
        ];

        // Si existe un ID_BUCKET, añadirlo a los datos de inserción
        if ($ID_BUCKET !== null) {
            $insertData['ID_BUCKET'] = $ID_BUCKET;
        }

        // Realizar la inserción y retornar el ID generado
        return DB::table('Finanzas.CONCILIACION_FLUJO')->insertGetId($insertData);
    }

}
