<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB; // Importar la clase DB

class ProrrateoGastos extends Model
{ 
    // Define the table associated with the model
    protected $table = 'REGISTRO_ENTRADAS_SALIDAS';

    // If the table doesn't use timestamps, disable them
    public $timestamps = false;


    public static function getTablaProrrateo()
    {
        // Ejecuta una consulta personalizada
        return DB::select("SELECT 
                            reg.ID_REGISTRO,
                            MAX(reg.FECHA) AS FECHA,
                            MAX(c.CUENTA) AS CUENTA,
                            MAX(reg.CARGO) AS CARGO,
                            MAX(reg.ID_CAT) AS ID_CAT,
                            MAX(reg.ABONO) AS ABONO,
                            MAX(cc.ID_COSTO) AS ID_COSTO,
                            MAX(b.BUCKET) AS BUCKET,
                            MAX(cc.ID_BUCKET) AS ID_BUCKET,
                            MAX(cc.ID_CENTRO_COSTO) AS ID_CENTRO_COSTO,
                            MAX(cos.CENTRO_COSTO) AS CENTRO_COSTO,
                            MAX(cc.COSTO) AS COSTO          
                        FROM 
                            REGISTRO_ENTRADAS_SALIDAS reg 
                        LEFT JOIN 
                            CAT_COMPLETO c 
                        ON 
                            reg.ID_CAT = c.ID_CAT 
                        LEFT JOIN 
                            Finanzas.CENTRO_COSTOS cc 
                        ON 
                            reg.ID_REGISTRO = cc.ID_REGISTRO
                        LEFT JOIN 
                            CAT_BUCKET b 
                        ON 
                            cc.ID_BUCKET = b.ID_BUCKET 
                        LEFT JOIN 
                            CAT_CENTRO_COSTOS cos
                        ON 
                            cc.ID_CENTRO_COSTO = cos.ID_CENTRO_COSTO
                        WHERE 
                            c.CUENTA LIKE '4%' OR
                            c.CUENTA LIKE '5%' OR
                            c.CUENTA LIKE '6%' OR
                            c.CUENTA LIKE '7%' OR
                        GROUP BY 
                            reg.ID_REGISTRO
                        ORDER BY 
                            reg.ID_REGISTRO DESC");
    }
    
    // FILTRO DE IDS_ DE SOLO LOS PRORRATEOS QUE SEAN VALIDOS
    // ADEMAS DE BUCKET Y COSTO
    public static function cat_bucket()
    {
        //traer datos
        $data = DB::table('CAT_BUCKET')
        ->select('ID_BUCKET', 'BUCKET')
        ->get();

        // devolver los datos
        return $data->toArray(); 
    }

    public static function updateBucket($idRegistro,$idBucket)
    {
        $rowsAffected = DB::table('CENTRO_COSTOS')
        ->where('ID_REGISTRO', $idRegistro)
        ->update(['ID_BUCKET' => $idBucket]);

        // Devuelve true si se actualizaron una o más filas, de lo contrario false
        return $rowsAffected > 0;
    }

    public static function costos()
    {
        return DB::table('Finanzas.CAT_CENTRO_COSTOS')
                 ->select('ID_CENTRO_COSTO', 'CENTRO_COSTO')
                 ->get();
    }

    public static function insertCostos($idValue, $idCentroCosto, $value, $bucket = null)
    {
        return DB::table('Finanzas.CENTRO_COSTOS')->insertGetId([
            'ID_REGISTRO' => $idValue,
            'ID_CENTRO_COSTO' => $idCentroCosto,
            'COSTO' => $value,
            'ID_BUCKET' => $bucket
        ]);
    }

    public static function valProrr($idvalue)
    {
        return DB::table('Finanzas.CENTRO_COSTOS')
        ->select('ID_CENTRO_COSTO', 'COSTO')
        ->where('ID_REGISTRO', $idvalue)
        ->get();

    }

    public static function updateCostos($idValue, $centroCostos)
    {
        // Obtener los registros existentes en la base de datos para este $idValue
        $existingCostos = DB::table('Finanzas.CENTRO_COSTOS')
            ->where('ID_REGISTRO', $idValue)
            ->pluck('COSTO', 'ID_CENTRO_COSTO')
            ->toArray();
    
        // Obtener los buckets existentes en la base de datos para este $idValue
        $existingBuckets = DB::table('Finanzas.CENTRO_COSTOS')
            ->where('ID_REGISTRO', $idValue)
            ->pluck('ID_BUCKET', 'ID_CENTRO_COSTO')
            ->toArray();
    
        $newIds = [];
        $idsToDelete = [];
    
        // Iterar sobre los nuevos datos de centros de costo
        foreach ($centroCostos as $centro) {
            $idCentroCosto = $centro['ID_CENTRO_COSTO'];
            $value = $centro['VALUE'];
    
            if (array_key_exists($idCentroCosto, $existingCostos)) {
                // Si el centro de costo ya existe, actualiza el valor si es necesario
                if ($existingCostos[$idCentroCosto] != $value) {
                    DB::table('Finanzas.CENTRO_COSTOS')
                        ->where('ID_REGISTRO', $idValue)
                        ->where('ID_CENTRO_COSTO', $idCentroCosto)
                        ->update(['COSTO' => $value]);
                }
            } else if ($idCentroCosto === null) {
                // Si $idCentroCosto es null, inserta el nuevo centro de costo con valores null
                DB::table('Finanzas.CENTRO_COSTOS')
                ->where('ID_REGISTRO', $idValue)
                ->where('ID_CENTRO_COSTO', $idCentroCosto)
                ->update(['COSTO' => '0.00']);
            } else {
                // Si el centro de costo no existe, consulta el bucket de un centro de costo existente
                // Utiliza el primer bucket encontrado (si existe) o null
                $bucket = !empty($existingBuckets) ? reset($existingBuckets) : null;
                
                // Inserta el nuevo centro de costo con el bucket consultado
                $newId = self::insertCostos($idValue, $idCentroCosto, $value, $bucket);
                $newIds[] = $newId;
            }
        }
    
        // Determinar los IDs que se deben eliminar
        $existingIds = array_keys($existingCostos);
        $newIds = array_column($centroCostos, 'ID_CENTRO_COSTO');
        $idsToDelete = array_diff($existingIds, $newIds);
    
        if (!empty($idsToDelete)) {
            // Eliminar los registros que ya no están en la lista
            DB::table('Finanzas.CENTRO_COSTOS')
                ->where('ID_REGISTRO', $idValue)
                ->whereIn('ID_CENTRO_COSTO', $idsToDelete)
                ->delete();
        }
    
        // Retornar el ID más alto de los insertados (si se insertó alguno)
        return !empty($newIds) ? max($newIds) : null;
    }
    
    

}