<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB; // Importar la clase DB

class RegistroentradasSalidas extends Model
{
    // Define the table associated with the model
    protected $table = 'REGISTRO_ENTRADAS_SALIDAS';

    // If the table doesn't use timestamps, disable them
    public $timestamps = false;


    public static function getTablaEntradasSalidas()
    {
        // Ejecuta una consulta personalizada
        return DB::select('SELECT r.ID_REGISTRO, r.FECHA,p.ID_POLIZA, p.POLIZA, c.ID_CAT,c.CUENTA, pro.ID_PROVEEDOR , pro.PROVEEDOR, r.DESCRIPCION, r.CARGO, r.ABONO FROM Finanzas.REGISTRO_ENTRADAS_SALIDAS r 
                            LEFT JOIN CAT_POLIZA p ON r.ID_POLIZA = p.ID_POLIZA 
                            LEFT JOIN CAT_COMPLETO c ON r.ID_CAT = c.ID_CAT 
                            LEFT JOIN CAT_PROVEEDORES pro ON r.ID_PROVEEDOR = pro.ID_PROVEEDOR ORDER BY r.ID_REGISTRO DESC'
                            );
    }


    public static function cat_poliza()
    {
        //traer datos
        $data = DB::table('CAT_POLIZA')
        ->select('ID_POLIZA', 'POLIZA')
        ->get();

        // devolver los datos
        return $data->toArray(); 
    }

    public static function cat_proveedores()
    {
        //traer datos
        $data = DB::table('CAT_PROVEEDORES')
        ->select('ID_PROVEEDOR', 'PROVEEDOR')
        ->get();

        // devolver los datos
        return $data->toArray(); 
    }

    public static function cat_completo()
    {
        //traer datos
        $data = DB::table('CAT_COMPLETO')
        ->select('ID_CAT', 'CUENTA')
        ->get();

        // devolver los datos
        return $data->toArray(); 
    }

    public static function addEntradasSalidas($data)
    {
        // Insertar datos en la tabla REGISTRO_ENTRADAS_SALIDAS 
        $inserted = DB::table('REGISTRO_ENTRADAS_SALIDAS')->insertGetId([
            'FECHA' => $data['fecha'],
            'ID_POLIZA' => $data['selectPoliza'],
            'ID_CAT' => $data['selectCuenta'],
            'ID_PROVEEDOR' => $data['selectProveedor'],
            'DESCRIPCION' => $data['descripcion'],
            'CARGO' => $data['cargo'],
            'ABONO' => $data['abono'],
        ]);

        // Verificar si la inserción fue exitosa
        if ($inserted) {
            return $inserted; // Inserción exitosa
        } else {
            return false; // Error en la inserción
        }
    }

    public static function updateRowsEntradasSalidas(array $rows)
    {
        $updatedCount = 0; // Contador para las filas actualizadas

        foreach ($rows as $row) {
            if (isset($row['ID_REGISTRO'])) {
                $updated = self::where('ID_REGISTRO', $row['ID_REGISTRO'])->update([
                    'FECHA' => $row['FECHA'],
                    'ID_POLIZA' => $row['POLIZA'],
                    'ID_CAT' => $row['CUENTA'],
                    'ID_PROVEEDOR' => $row['PROVEEDOR'],
                    'DESCRIPCION' => $row['DESCRIPCION'],
                    'CARGO' => $row['CARGO'],
                    'ABONO' => $row['ABONO'],
                ]);

                if ($updated) {
                    $updatedCount++;
                }
            }
        }

        // Comprobar si se actualizaron todas las filas
        if ($updatedCount === count($rows)) { //si si se actualizo
            return true; // Todas las filas se actualizaron exitosamente
        } else {
            return false; // No todas las filas se actualizaron
        }
    }

    public static function delEntradasSalidas($idFila)
    {
        // Asegúrate de que $idFila es un número entero
        $idFila = (int) $idFila;

        $deletedCostos = DB::table('Finanzas.CENTRO_COSTOS')
        ->where('ID_REGISTRO', $idFila)
        ->delete();

        $deletedConFlujo = DB::table('Finanzas.CONCILIACION_FLUJO')
        ->where('ID_REGISTRO', $idFila)
        ->delete();

        // Finalmente, eliminar el registro en REGISTRO_ENTRADAS_SALIDAS
        $deletedRegistro  = DB::table('REGISTRO_ENTRADAS_SALIDAS')
            ->where('ID_REGISTRO', $idFila)
            ->delete();

        if ($deletedRegistro ) {
            return true; // Éxito
        }else{
            return false; // Registro no encontrado
        } // Retorna true si se eliminó el registro, false si no
    }

    public static function proratteoInsert($idFila)
    {
        $inserted = DB::table('PRORRATEO_GASTOS')->insert([
            'ID_REGISTRO' => $idFila,
        ]);

        // Verificar si la inserción fue exitosa
        if ($inserted) {
            return true; // Inserción exitosa
        } else {
            return false; // Error en la inserción
        }
    }

    public static function conciliacionflujoInsert($idFila)
    {
        $inserted = DB::table('CONCILIACION_FLUJO')->insert([
            'ID_REGISTRO' => $idFila,
        ]);

        // Verificar si la inserción fue exitosa
        if ($inserted) {
            return true; // Inserción exitosa
        } else {
            return false; // Error en la inserción
        }
    }

    public static function conciliacionflujoUpdate($idFila)
    {
          // Asegúrate de que $idFila es un número entero
          $idFila = (int) $idFila;
          $deleteCon= FALSE;
          // Verificar si el ID está en CONCILIACION_FLUJO
          $existsInConciliacionFlujo = DB::table('PRORRATEO_GASTOS')
              ->where('ID_REGISTRO', $idFila)
              ->exists();
  
          // Eliminar registros relacionados en CONCILIACION_FLUJO si existen
          if ($existsInConciliacionFlujo) {
            $deleteCon = DB::table('PRORRATEO_GASTOS')
                  ->where('ID_REGISTRO', $idFila)
                  ->delete();
          }

            // Verificar si la inserción fue exitosa
            if ($deleteCon) {
                return true; // Inserción exitosa
            } else {
                return false; // Error en la inserción
            }
    }

    public static function proratteoUpdate($idFila)
    {
        $idFila = (int) $idFila;
        $delProrrateo= FALSE;
        // Verificar si el ID está en PRORRATEO_GASTOS
        $existsInProrateoGastos = DB::table('CONCILIACION_FLUJO')
            ->where('ID_REGISTRO', $idFila)
            ->exists();


        // Eliminar registros relacionados en PRORRATEO_GASTOS si existen
        if ($existsInProrateoGastos) {
            $delProrrateo = DB::table('CONCILIACION_FLUJO')
                ->where('ID_REGISTRO', $idFila)
                ->delete();
        }
        // Verificar si la inserción fue exitosa
        if ($delProrrateo) {
            return true; // Inserción exitosa
        } else {
            return false; // Error en la inserción
        }
    }

}
